@@ -6,7 +6,7 @@ use Carp qw( carp );
 use File::Basename qw( basename );
 
 # ABSTRACT: Interface for manipulating ar archives with libarchive
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 unless($^O eq 'MSWin32')
 {
@@ -211,7 +211,7 @@ Archive::Ar::Libarchive - Interface for manipulating ar archives with libarchive
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -255,7 +255,9 @@ circumstances.
 The main advantage of L<Archive::Ar> over this module is that it is 
 written in pure perl, and thus does not require a compiler or 
 libarchive.  The advantage of this module (at least as of this writing) 
-is that it supports GNU and BSD extensions for longer member filenames.
+is that it supports GNU (read) and BSD (read and write) extensions for 
+longer member filenames.  As an XS module using libarchive it may also
+be faster.
 
 =head1 METHODS
 
@@ -407,14 +409,14 @@ of files successfully removed from the archive.
  $ar->set_output_format_bsd;
 
 Sets the output format produced by L<Archive::Ar::Libarchive#write> to 
-use BSD format. Note: this method is not available in l<Archive::Ar>.
+use BSD format. Note: this method is not available in L<Archive::Ar>.
 
 =head2 set_output_format_svr4
 
  $ar->set_output_format_svr4;
 
 Sets the output format produced by L<Archive::Ar::Libarchive#write> to 
-System VR4 format. Note: this method is not available in l<Archive::Ar>.
+System VR4 format. Note: this method is not available in L<Archive::Ar>.
 
 =head2 DEBUG
 
